"""Initial schema

Revision ID: cd7c4df10683
Revises: 
Create Date: 2018-01-02 16:07:40.063391

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision = 'cd7c4df10683'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('customer',
    sa.Column('id', sa.String(length=64), nullable=False),
    sa.Column('stripe_customer_id', sa.String(length=255), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('package',
    sa.Column('id', sa.BigInteger(), nullable=False),
    sa.Column('owner', sa.String(length=64), nullable=False),
    sa.Column('name', sa.String(length=64), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index('idx_owner_name', 'package', ['owner', 'name'], unique=True)
    op.create_table('s3_blob',
    sa.Column('id', sa.BigInteger(), nullable=False),
    sa.Column('owner', sa.String(length=64), nullable=False),
    sa.Column('hash', sa.String(length=64), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index('idx', 's3_blob', ['owner', 'hash'], unique=True)
    op.create_table('access',
    sa.Column('package_id', sa.BigInteger(), nullable=False),
    sa.Column('user', sa.String(length=64), nullable=False),
    sa.ForeignKeyConstraint(['package_id'], ['package.id'], ),
    sa.PrimaryKeyConstraint('package_id', 'user')
    )
    op.create_table('instance',
    sa.Column('id', sa.BigInteger(), nullable=False),
    sa.Column('package_id', sa.BigInteger(), nullable=False),
    sa.Column('hash', sa.String(length=64), nullable=False),
    sa.Column('created_at', sa.DateTime(), server_default=sa.text('now()'), nullable=False),
    sa.Column('created_by', sa.String(length=64), nullable=False),
    sa.Column('updated_at', sa.DateTime(), server_default=sa.text('now()'), nullable=False),
    sa.Column('updated_by', sa.String(length=64), nullable=False),
    sa.Column('contents', postgresql.JSONB(astext_type=sa.Text()), nullable=False),
    sa.ForeignKeyConstraint(['package_id'], ['package.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index('idx_hash', 'instance', ['package_id', 'hash'], unique=True)
    op.create_table('invitation',
    sa.Column('id', sa.BigInteger(), nullable=False),
    sa.Column('package_id', sa.BigInteger(), nullable=True),
    sa.Column('email', sa.String(length=254), nullable=False),
    sa.Column('invited_at', sa.DateTime(), server_default=sa.text('now()'), nullable=False),
    sa.ForeignKeyConstraint(['package_id'], ['package.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_table('instance_blob',
    sa.Column('instance_id', sa.BigInteger(), nullable=True),
    sa.Column('blob_id', sa.BigInteger(), nullable=True),
    sa.ForeignKeyConstraint(['blob_id'], ['s3_blob.id'], ),
    sa.ForeignKeyConstraint(['instance_id'], ['instance.id'], )
    )
    op.create_table('log',
    sa.Column('id', sa.BigInteger(), nullable=False),
    sa.Column('package_id', sa.BigInteger(), nullable=False),
    sa.Column('instance_id', sa.BigInteger(), nullable=True),
    sa.Column('created', sa.DateTime(), server_default=sa.text('now()'), nullable=False),
    sa.Column('author', sa.String(length=64), nullable=False),
    sa.ForeignKeyConstraint(['instance_id'], ['instance.id'], ),
    sa.ForeignKeyConstraint(['package_id'], ['package.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_log_package_id'), 'log', ['package_id'], unique=False)
    op.create_table('tag',
    sa.Column('package_id', sa.BigInteger(), nullable=False),
    sa.Column('tag', sa.String(length=64), nullable=False),
    sa.Column('instance_id', sa.BigInteger(), nullable=True),
    sa.ForeignKeyConstraint(['instance_id'], ['instance.id'], ),
    sa.ForeignKeyConstraint(['package_id'], ['package.id'], ),
    sa.PrimaryKeyConstraint('package_id', 'tag')
    )
    op.create_table('version',
    sa.Column('package_id', sa.BigInteger(), nullable=False),
    sa.Column('version', sa.String(length=64), nullable=False),
    sa.Column('instance_id', sa.BigInteger(), nullable=True),
    sa.Column('user_version', sa.String(length=64), nullable=False),
    sa.ForeignKeyConstraint(['instance_id'], ['instance.id'], ),
    sa.ForeignKeyConstraint(['package_id'], ['package.id'], ),
    sa.PrimaryKeyConstraint('package_id', 'version')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('version')
    op.drop_table('tag')
    op.drop_index(op.f('ix_log_package_id'), table_name='log')
    op.drop_table('log')
    op.drop_table('instance_blob')
    op.drop_table('invitation')
    op.drop_index('idx_hash', table_name='instance')
    op.drop_table('instance')
    op.drop_table('access')
    op.drop_index('idx', table_name='s3_blob')
    op.drop_table('s3_blob')
    op.drop_index('idx_owner_name', table_name='package')
    op.drop_table('package')
    op.drop_table('customer')
    # ### end Alembic commands ###
